library flutter_combo_box;

// ABOUT THE DEVELOPER
//
// Contacts:
//      - Names: Chris Simba Mukasa
//      - Mail: mukasa.chris7@gmail.com
//      - Phone: +243 994 802 444
//      - Address: Av. de la mission, Himbi 2, Goma, Nord-Kivu, RDC
//
// Skills:
//      - Android Native development,
//      - Flutter developer [Android, IOS, Web and Desktop],
//      - Database Manager,
//      - ApiRestFull developer (With pure PHP),
//      - Desktop Apps developer (VB.net, C#)
//
//  Copyright (c) Aug 2021.
//  All rights reserved.
//

import 'package:flutter/material.dart';

import 'components/combo_box.dart';

class ComboBoxFuture extends StatefulWidget {
  final String label;
  final String hint;
  final String loadingHint;
  final Color accent;
  final double radius;
  final Future<List<dynamic>> datas;
  final ValueChanged<dynamic>? onChanged;

  const ComboBoxFuture({ Key? key, required this.label, required this.hint, this.loadingHint = '', this.accent = Colors.blue, this.radius = 4, required this.datas, this.onChanged}) : super(key: key);

  @override
  _ComboBoxFutureState createState() => _ComboBoxFutureState();
}

class _ComboBoxFutureState extends State<ComboBoxFuture> {
  dynamic selectedValue;

  @override
  Widget build(BuildContext context) {
    return FutureBuilder<List<dynamic>>(
      initialData: [],
      future: widget.datas,
      builder: (_, snapshot) {
        if (!snapshot.hasData) {
          Text(widget.loadingHint);
        } else {
          return DropdownButtonFormField(
            decoration: InputDecoration(
              contentPadding: EdgeInsets.symmetric(horizontal: 20, vertical: 0),
              labelText: widget.label,
              hintText: widget.hint,
              hintStyle: TextStyle(color: Colors.grey, fontSize: 16, fontWeight: FontWeight.w800),
              alignLabelWithHint: true,
              border: OutlineInputBorder(
                borderRadius: BorderRadius.circular(widget.radius),
                borderSide: BorderSide(color: Color(0xFFE7EAEE)),
                gapPadding: 16,
              ),
              enabledBorder: OutlineInputBorder(
                borderRadius: BorderRadius.circular(widget.radius),
                borderSide: BorderSide(color: Color(0xFFE7EAEE)),
                gapPadding: 16,
              ),
              focusedBorder: OutlineInputBorder(
                borderRadius: BorderRadius.circular(widget.radius),
                borderSide: BorderSide(color: Color(0xFFE7EAEE)),
                gapPadding: 16,
              ),
            ),
            items: snapshot.data!.map((item) {
              return DropdownMenuItem(
                child: TileTitle(title: item, accent: widget.accent),
                value: item,
              );
            }).toList(),
            onChanged: (value) {
              setState(() => selectedValue = value);
              widget.onChanged!(selectedValue);
            },
            value: selectedValue,
          );
        }
        return Text(widget.hint);
      },
    );
  }
}